# vizkit

Data plotting and visualization platform.

## Getting Started

1. `pipx install vizkit`
2. Create a data folder: `mkdir vizkit-example && cd vizkit-example`
3. Put some .csv files into the data folder, for example [this one](https://gist.github.com/wenyuzhao/ec38429b9e176ae922ef70009a553a95).
4. Run `vizkit --open` to start the server.

## Generate Reports Using the [Harness](https://github.com/wenyuzhao/harness) Bench Tool

Running a benchmark with the `--upload` flag will automatically upload the results data to [r.harness.rs](https://r.harness.rs).

Example: `harness run --upload`.

## Generate Reports Using [running-ng](https://github.com/anupli/running-ng)

WIP...
